SIA_CODES = {
    "AA": {
        "code": "AA",
        "concerns": "Condition number",
        "description": "An attempt to substitute an alternate alarm panel "
        "for a secure panel has been made",
        "type": "Alarm – Panel Substitution",
    },
    "AB": {
        "code": "AB",
        "concerns": "Zone or point",
        "description": "An event message was not sent due to User action",
        "type": "Abort",
    },
    "AF": {
        "code": "AF",
        "concerns": "Zone or point",
        "description": "Scenario",
        "type": "Arming Event",
    },
    "AN": {
        "code": "AN",
        "concerns": "Zone or point",
        "description": "An analog fire sensor has been restored to normal operation",
        "type": "Analog Restoral",
    },
    "AR": {
        "code": "AR",
        "concerns": "Unused",
        "description": "AC power has been restored",
        "type": "AC Restoral",
    },
    "AS": {
        "code": "AS",
        "concerns": "Zone or point",
        "description": "An analog fire sensor needs to be cleaned or calibrated",
        "type": "Analog Service",
    },
    "AT": {
        "code": "AT",
        "concerns": "Unused",
        "description": "AC power has been failed",
        "type": "AC Trouble",
    },
    "BA": {
        "code": "BA",
        "concerns": "Zone or point",
        "description": "Burglary zone has been violated while armed",
        "type": "Burglary Alarm",
    },
    "BB": {
        "code": "BB",
        "concerns": "Zone or point",
        "description": "Burglary zone has been bypassed",
        "type": "Burglary Bypass",
    },
    "BC": {
        "code": "BC",
        "concerns": "User number",
        "description": "Alarm has been cancelled by authorized user",
        "type": "Burglary Cancel",
    },
    "BD": {
        "code": "BD",
        "concerns": "Zone or point",
        "description": "A non-fire zone has been violated after a Swinger "
        "Shutdown on the zone",
        "type": "Swinger Trouble",
    },
    "BE": {
        "code": "BE",
        "concerns": "Zone or point",
        "description": "A non-fire zone restores to normal from a Swinger "
        "Trouble state",
        "type": "Swinger Trouble Restore",
    },
    "BG": {
        "code": "BG",
        "concerns": "Zone or point",
        "description": "A point assigned to a Cross Point group has gone "
        "into alarm but the Cross Point remained normal",
        "type": "Unverified Event - Burglary",
    },
    "BH": {
        "code": "BH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Burglary Alarm Restore",
    },
    "BJ": {
        "code": "BJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Burglary Trouble Restore",
    },
    "BM": {
        "code": "BM",
        "concerns": "Zone or point",
        "description": "Burglary alarm w/cross point also in alarm - alarm verified",
        "type": "Burglary Alarm - Cross Point",
    },
    "BR": {
        "code": "BR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Burglary Restoral",
    },
    "BS": {
        "code": "BS",
        "concerns": "Zone or point",
        "description": "Unsafe intrusion detection system condition",
        "type": "Burglary Supervisory",
    },
    "BT": {
        "code": "BT",
        "concerns": "Zone or point",
        "description": "Burglary zone disabled by fault",
        "type": "Burglary Trouble",
    },
    "BU": {
        "code": "BU",
        "concerns": "Zone or point",
        "description": "Zone bypass has been removed",
        "type": "Burglary Unbypass",
    },
    "BV": {
        "code": "BV",
        "concerns": "Area number",
        "description": "A burglary alarm has occurred and been verified "
        "within programmed conditions. (zone or point not "
        "sent)",
        "type": "Burglary Verified",
    },
    "BX": {
        "code": "BX",
        "concerns": "Zone or point",
        "description": "Burglary zone activated during testing",
        "type": "Burglary Test",
    },
    "BZ": {
        "code": "BZ",
        "concerns": "Zone or point",
        "description": "A non-fire Supervisory point has gone missing",
        "type": "Missing Supervision",
    },
    "CA": {
        "code": "CA",
        "concerns": "Area number",
        "description": "System armed automatically",
        "type": "Automatic Closing",
    },
    "CB": {
        "code": "CB",
        "concerns": "Area number",
        "description": "Group has been disarmed automatically",
        "type": "Arming Event",
    },
    "CC": {
        "code": "CC",
        "concerns": "Area number",
        "description": "Unsuccessful arming attempt",
        "type": "Arming Event",
    },
    "CD": {
        "code": "CD",
        "concerns": "Area number",
        "description": "The system has not been armed for a programmed amount of time",
        "type": "Closing Delinquent",
    },
    "CE": {
        "code": "CE",
        "concerns": "User number",
        "description": "Extend closing time",
        "type": "Closing Extend",
    },
    "CF": {
        "code": "CF",
        "concerns": "User number",
        "description": "System armed, some zones not ready",
        "type": "Forced Closing",
    },
    "CG": {
        "code": "CG",
        "concerns": "Area number",
        "description": "System has been partially armed",
        "type": "Close Area",
    },
    "CI": {
        "code": "CI",
        "concerns": "Area number",
        "description": "An area has not been armed at the end of the closing window",
        "type": "Fail to Close",
    },
    "CJ": {
        "code": "CJ",
        "concerns": "User number",
        "description": "An area was armed after the closing window",
        "type": "Late Close",
    },
    "CK": {
        "code": "CK",
        "concerns": "User number",
        "description": "An area was armed before the closing window",
        "type": "Early Close",
    },
    "CL": {
        "code": "CL",
        "concerns": "User number",
        "description": "System armed, normal",
        "type": "Closing Report",
    },
    "CM": {
        "code": "CM",
        "concerns": "Zone or point",
        "description": "A point has gone missing within 2 minutes of closing",
        "type": "Missing Alarm - Recent Closing",
    },
    "CO": {
        "code": "CO",
        "concerns": "Condition number",
        "description": "A command has been sent to an expansion/peripheral device",
        "type": "Command Sent",
    },
    "CP": {
        "code": "CP",
        "concerns": "User number",
        "description": "System armed automatically",
        "type": "Automatic Closing",
    },
    "CQ": {
        "code": "CQ",
        "concerns": "User number",
        "description": "The system was armed from a remote location",
        "type": "Remote Closing",
    },
    "CR": {
        "code": "CR",
        "concerns": "User number",
        "description": "An alarm occurred within five minutes after the "
        "system was closed",
        "type": "Recent Closing",
    },
    "CS": {
        "code": "CS",
        "concerns": "Zone or point",
        "description": "Account has been armed by keyswitch",
        "type": "Closing Keyswitch",
    },
    "CT": {
        "code": "CT",
        "concerns": "Area number",
        "description": "System was not disarmed on time",
        "type": "Late to Open",
    },
    "CW": {
        "code": "CW",
        "concerns": "Area number",
        "description": "Header for a force armed session, forced point msgs may follow",
        "type": "Was Force Armed",
    },
    "CX": {
        "code": "CX",
        "concerns": "Custom Function number",
        "description": "The panel has executed a preprogrammed set of instructions",
        "type": "Custom Function Executed",
    },
    "CZ": {
        "code": "CZ",
        "concerns": "Zone or point",
        "description": "A point, as opposed to a whole area or account, has closed",
        "type": "Point Closing",
    },
    "DA": {
        "code": "DA",
        "concerns": "User number",
        "description": "An access ID has been added to the controller",
        "type": "Card Assigned",
    },
    "DB": {
        "code": "DB",
        "concerns": "User number",
        "description": "An access ID has been deleted from the controller",
        "type": "Card Deleted",
    },
    "DC": {
        "code": "DC",
        "concerns": "Door number",
        "description": "Access to all users prohibited",
        "type": "Access Closed",
    },
    "DD": {
        "code": "DD",
        "concerns": "Door number",
        "description": "Access denied, unknown code",
        "type": "Access Denied",
    },
    "DE": {
        "code": "DE",
        "concerns": "Door number",
        "description": "An access point was opened via a Request to Enter device",
        "type": "Request to Enter",
    },
    "DF": {
        "code": "DF",
        "concerns": "Door number",
        "description": "Door opened without access request",
        "type": "Door Forced",
    },
    "DG": {
        "code": "DG",
        "concerns": "Door number",
        "description": "Door access granted",
        "type": "Access Granted",
    },
    "DH": {
        "code": "DH",
        "concerns": "Door number",
        "description": "An access point in a Door Left Open state has restored",
        "type": "Door Left Open - Restoral",
    },
    "DI": {
        "code": "DI",
        "concerns": "Door number",
        "description": "Access denied because credential has not exited area "
        "before attempting to re-enter same area",
        "type": "Access Denied – Passback",
    },
    "DJ": {
        "code": "DJ",
        "concerns": "Door number",
        "description": "An access point has been forced open in an unarmed area",
        "type": "Door Forced - Trouble",
    },
    "DK": {
        "code": "DK",
        "concerns": "Door number",
        "description": "Access denied, known code",
        "type": "Access Lockout",
    },
    "DL": {
        "code": "DL",
        "concerns": "Door number",
        "description": "An open access point when open time expired in an armed area",
        "type": "Door Left Open - Alarm",
    },
    "DM": {
        "code": "DM",
        "concerns": "Door number",
        "description": "An open access point when open time expired in an unarmed area",
        "type": "Door Left Open - Trouble",
    },
    "DN": {
        "code": "DN",
        "concerns": "Door number",
        "description": "An access point was open when the door cycle time expired",
        "type": "Door Left Open (non-alarm, non-trouble)",
    },
    "DO": {
        "code": "DO",
        "concerns": "Door number",
        "description": "Access to authorized users allowed",
        "type": "Access Open",
    },
    "DP": {
        "code": "DP",
        "concerns": "Door number",
        "description": "An access request was denied because the request is "
        "occurring outside the user’s authorized time "
        "window(s)",
        "type": "Access Denied - Unauthorized Time",
    },
    "DQ": {
        "code": "DQ",
        "concerns": "Door number",
        "description": "An access request was denied because the user was "
        "not authorized in this area when the area was armed",
        "type": "Access Denied - Unauthorized Arming State",
    },
    "DR": {
        "code": "DR",
        "concerns": "Door number",
        "description": "Access alarm/trouble condition eliminated",
        "type": "Door Restoral",
    },
    "DS": {
        "code": "DS",
        "concerns": "Door number",
        "description": "Identifies door for next report",
        "type": "Door Station",
    },
    "DT": {
        "code": "DT",
        "concerns": "Unused",
        "description": "Access system trouble",
        "type": "Access Trouble",
    },
    "DU": {
        "code": "DU",
        "concerns": "Dealer ID",
        "description": "Dealer ID number",
        "type": "Dealer ID",
    },
    "DV": {
        "code": "DV",
        "concerns": "Door number",
        "description": "An access request was denied because the user is not "
        "authorized in this area",
        "type": "Access Denied - Unauthorized Entry Level",
    },
    "DW": {
        "code": "DW",
        "concerns": "Door number",
        "description": "An access request was denied because the doors "
        "associated Interlock point is open",
        "type": "Access Denied - Interlock",
    },
    "DX": {
        "code": "DX",
        "concerns": "Door number",
        "description": "An access point was opened via a Request to Exit device",
        "type": "Request to Exit",
    },
    "DY": {
        "code": "DY",
        "concerns": "Door number",
        "description": "The door’s lock has been engaged",
        "type": "Door Locked",
    },
    "DZ": {
        "code": "DZ",
        "concerns": "Door number",
        "description": "An access request was denied because the door has "
        "been placed in an Access Closed state",
        "type": "Access Denied - Door Secured",
    },
    "EA": {
        "code": "EA",
        "concerns": "Zone or point",
        "description": "An exit zone remained violated at the end of the "
        "exit delay period",
        "type": "Exit Alarm",
    },
    "EE": {
        "code": "EE",
        "concerns": "User number",
        "description": "An exit zone remained violated at the end of the "
        "exit delay period",
        "type": "Exit Error",
    },
    "EJ": {
        "code": "EJ",
        "concerns": "Expansion device number",
        "description": "Expansion device tamper restoral",
        "type": "Expansion Tamper Restore",
    },
    "EM": {
        "code": "EM",
        "concerns": "Expansion device number",
        "description": "Expansion device missing",
        "type": "Expansion Device Missing",
    },
    "EN": {
        "code": "EN",
        "concerns": "Expansion device number",
        "description": "Expansion device communications re-established",
        "type": "Expansion Missing Restore",
    },
    "ER": {
        "code": "ER",
        "concerns": "Expander number",
        "description": "Expansion device trouble eliminated",
        "type": "Expansion Restoral",
    },
    "ES": {
        "code": "ES",
        "concerns": "Expansion device number",
        "description": "Expansion device enclosure tamper",
        "type": "Expansion Device Tamper",
    },
    "ET": {
        "code": "ET",
        "concerns": "Expander number",
        "description": "Expansion device trouble",
        "type": "Expansion Trouble",
    },
    "EX": {
        "code": "EX",
        "concerns": "Device number",
        "description": "A specific reportable condition is detected on an "
        "external device",
        "type": "External Device Condition",
    },
    "EZ": {
        "code": "EZ",
        "concerns": "Point number",
        "description": "A point remained missing at the end of the exit delay period",
        "type": "Missing Alarm - Exit Error",
    },
    "FA": {
        "code": "FA",
        "concerns": "Zone or point",
        "description": "Fire condition detected",
        "type": "Fire Alarm",
    },
    "FB": {
        "code": "FB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Fire Bypass",
    },
    "FC": {
        "code": "FC",
        "concerns": "Zone or point",
        "description": "A Fire Alarm has been cancelled by an authorized person",
        "type": "Fire Cancel",
    },
    "FG": {
        "code": "FG",
        "concerns": "Zone or point",
        "description": "A point assigned to a Cross Point group has gone "
        "into alarm but the Cross Point remained normal",
        "type": "Unverified Event – Fire",
    },
    "FH": {
        "code": "FH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Fire Alarm Restore",
    },
    "FI": {
        "code": "FI",
        "concerns": "Area number",
        "description": "The transmitter area's fire test has begun",
        "type": "Fire Test Begin",
    },
    "FJ": {
        "code": "FJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Fire Trouble Restore",
    },
    "FK": {
        "code": "FK",
        "concerns": "Area number",
        "description": "The transmitter area's fire test has ended",
        "type": "Fire Test End",
    },
    "FL": {
        "code": "FL",
        "concerns": "Zone or point",
        "description": "The fire panel’s sounder was silenced by command",
        "type": "Fire Alarm Silenced",
    },
    "FM": {
        "code": "FM",
        "concerns": "Point number",
        "description": "Fire Alarm with Cross Point also in alarm verifying "
        "the Fire Alarm",
        "type": "Fire Alarm - Cross Point",
    },
    "FQ": {
        "code": "FQ",
        "concerns": "Zone or point",
        "description": "A fire supervisory zone that was in trouble "
        "condition has now restored to normal",
        "type": "Fire Supervisory Trouble Restore",
    },
    "FR": {
        "code": "FR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Fire Restoral",
    },
    "FS": {
        "code": "FS",
        "concerns": "Zone or point",
        "description": "Unsafe fire detection system condition",
        "type": "Fire Supervisory",
    },
    "FT": {
        "code": "FT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Fire Trouble",
    },
    "FU": {
        "code": "FU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Fire Unbypass",
    },
    "FV": {
        "code": "FV",
        "concerns": "Zone or point",
        "description": "A fire supervision zone that was in alarm has "
        "restored to normal",
        "type": "Fire Supervision Restore",
    },
    "FW": {
        "code": "FW",
        "concerns": "Zone or point",
        "description": "A fire supervisory zone is now in a trouble condition",
        "type": "Fire Supervisory Trouble",
    },
    "FX": {
        "code": "FX",
        "concerns": "Zone or point",
        "description": "Fire zone activated during test",
        "type": "Fire Test",
    },
    "FY": {
        "code": "FY",
        "concerns": "Zone or point",
        "description": "A fire point is now logically missing",
        "type": "Missing Fire Trouble",
    },
    "FZ": {
        "code": "FZ",
        "concerns": "Zone or point",
        "description": "A Fire Supervisory point has gone missing",
        "type": "Missing Fire Supervision",
    },
    "GA": {
        "code": "GA",
        "concerns": "Zone or point",
        "description": "Gas alarm condition detected",
        "type": "Gas Alarm",
    },
    "GB": {
        "code": "GB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Gas Bypass",
    },
    "GH": {
        "code": "GH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Gas Alarm Restore",
    },
    "GJ": {
        "code": "GJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Gas Trouble Restore",
    },
    "GR": {
        "code": "GR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Gas Restoral",
    },
    "GS": {
        "code": "GS",
        "concerns": "Zone or point",
        "description": "Unsafe gas detection system condition",
        "type": "Gas Supervisory",
    },
    "GT": {
        "code": "GT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Gas Trouble",
    },
    "GU": {
        "code": "GU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Gas Unbypass",
    },
    "GX": {
        "code": "GX",
        "concerns": "Zone or point",
        "description": "Zone activated during test",
        "type": "Gas Test",
    },
    "HA": {
        "code": "HA",
        "concerns": "Zone or point",
        "description": "Silent alarm, user under duress",
        "type": "Holdup Alarm",
    },
    "HB": {
        "code": "HB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Holdup Bypass",
    },
    "HH": {
        "code": "HH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Holdup Alarm Restore",
    },
    "HJ": {
        "code": "HJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Holdup Trouble Restore",
    },
    "HR": {
        "code": "HR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Holdup Restoral",
    },
    "HS": {
        "code": "HS",
        "concerns": "Zone or point",
        "description": "Unsafe holdup system condition",
        "type": "Holdup Supervisory",
    },
    "HT": {
        "code": "HT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Holdup Trouble",
    },
    "HU": {
        "code": "HU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Holdup Unbypass",
    },
    "IA": {
        "code": "IA",
        "concerns": "Point number",
        "description": "A specific, reportable condition is detected on a device",
        "type": "Equipment Failure Condition",
    },
    "IR": {
        "code": "IR",
        "concerns": "Point number",
        "description": "The equipment condition has been restored to normal",
        "type": "Equipment Fail - Restoral",
    },
    "JA": {
        "code": "JA",
        "concerns": "Area number",
        "description": "Too many unsuccessful attempts have been made to "
        "enter a user ID",
        "type": "User code Tamper",
    },
    "JC": {
        "code": "JC",
        "concerns": "Area number",
        "description": "Break password restore",
        "type": "User code tamper canceled",
    },
    "JD": {
        "code": "JD",
        "concerns": "User number",
        "description": "The date was changed in the transmitter/receiver",
        "type": "Date Changed",
    },
    "JH": {
        "code": "JH",
        "concerns": "User number",
        "description": "The transmitter's holiday schedule has been changed",
        "type": "Holiday Changed",
    },
    "JK": {
        "code": "JK",
        "concerns": "User number",
        "description": "A designated user passcode has not been entered "
        "during a scheduled time window",
        "type": "Latchkey Alert",
    },
    "JL": {
        "code": "JL",
        "concerns": "Unused",
        "description": "The transmitter's log memory has reached its threshold level",
        "type": "Log Threshold",
    },
    "JO": {
        "code": "JO",
        "concerns": "Unused",
        "description": "The transmitter's log memory has overflowed",
        "type": "Log Overflow",
    },
    "JP": {
        "code": "JP",
        "concerns": "User number",
        "description": "A designated user passcode has been used to gain "
        "access to the premises.",
        "type": "User On Premises",
    },
    "JR": {
        "code": "JR",
        "concerns": "Area number",
        "description": "An automatic scheduled event was executed",
        "type": "Schedule Executed",
    },
    "JS": {
        "code": "JS",
        "concerns": "User number",
        "description": "An automatic schedule was changed",
        "type": "Schedule Changed",
    },
    "JT": {
        "code": "JT",
        "concerns": "User number",
        "description": "The time was changed in the transmitter/receiver",
        "type": "Time Changed",
    },
    "JV": {
        "code": "JV",
        "concerns": "User number",
        "description": "A user's code has been changed",
        "type": "User code Changed",
    },
    "JX": {
        "code": "JX",
        "concerns": "User number",
        "description": "A user's code has been removed",
        "type": "User code Deleted",
    },
    "JY": {
        "code": "JY",
        "concerns": "User number",
        "description": "A user’s code has been added",
        "type": "User code Added",
    },
    "JZ": {
        "code": "JZ",
        "concerns": "User number",
        "description": "A user’s authority level has been set",
        "type": "User Level Set",
    },
    "KA": {
        "code": "KA",
        "concerns": "Zone or point",
        "description": "High temperature detected on premise",
        "type": "Heat Alarm",
    },
    "KB": {
        "code": "KB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Heat Bypass",
    },
    "KH": {
        "code": "KH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Heat Alarm Restore",
    },
    "KJ": {
        "code": "KJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Heat Trouble Restore",
    },
    "KR": {
        "code": "KR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Heat Restoral",
    },
    "KS": {
        "code": "KS",
        "concerns": "Zone or point",
        "description": "Unsafe heat detection system condition",
        "type": "Heat Supervisory",
    },
    "KT": {
        "code": "KT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Heat Trouble",
    },
    "KU": {
        "code": "KU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Heat Unbypass",
    },
    "LB": {
        "code": "LB",
        "concerns": "Unused",
        "description": "Begin local programming",
        "type": "Local Program",
    },
    "LD": {
        "code": "LD",
        "concerns": "Unused",
        "description": "Access code incorrect",
        "type": "Local Program Denied",
    },
    "LE": {
        "code": "LE",
        "concerns": "Unused",
        "description": "The listen-in session has been terminated",
        "type": "Listen-in Ended",
    },
    "LF": {
        "code": "LF",
        "concerns": "Unused",
        "description": "The listen-in session with the RECEIVER has begun",
        "type": "Listen-in Begin",
    },
    "LR": {
        "code": "LR",
        "concerns": "Line number",
        "description": "Phone line restored to service",
        "type": "Phone Line Restoral",
    },
    "LS": {
        "code": "LS",
        "concerns": "Unused",
        "description": "Local programming successful",
        "type": "Local Program Success",
    },
    "LT": {
        "code": "LT",
        "concerns": "Line number",
        "description": "Phone line trouble report",
        "type": "Phone Line Trouble",
    },
    "LU": {
        "code": "LU",
        "concerns": "Unused",
        "description": "Local programming unsuccessful",
        "type": "Local Program Fail",
    },
    "LX": {
        "code": "LX",
        "concerns": "Unused",
        "description": "A local programming session has been terminated",
        "type": "Local Programming Ended",
    },
    "MA": {
        "code": "MA",
        "concerns": "Zone or point",
        "description": "Emergency assistance request",
        "type": "Medical Alarm",
    },
    "MB": {
        "code": "MB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Medical Bypass",
    },
    "MH": {
        "code": "MH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Medical Alarm Restore",
    },
    "MI": {
        "code": "MI",
        "concerns": "Message number",
        "description": "A canned message is being sent",
        "type": "Message",
    },
    "MJ": {
        "code": "MJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Medical Trouble Restore",
    },
    "MR": {
        "code": "MR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Medical Restoral",
    },
    "MS": {
        "code": "MS",
        "concerns": "Zone or point",
        "description": "Unsafe system condition exists",
        "type": "Medical Supervisory",
    },
    "MT": {
        "code": "MT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Medical Trouble",
    },
    "MU": {
        "code": "MU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Medical Unbypass",
    },
    "NA": {
        "code": "NA",
        "concerns": "Zone number",
        "description": "There has been no zone activity for a programmed "
        "amount of time",
        "type": "No Activity",
    },
    "NB": {
        "code": "NB",
        "concerns": "Area number",
        "description": "Scenario",
        "type": "Arming Event",
    },
    "NC": {
        "code": "NC",
        "concerns": "Network number",
        "description": "A communications network has a specific reportable condition",
        "type": "Network Condition",
    },
    "ND": {
        "code": "ND",
        "concerns": "Area number",
        "description": "Night mode deactivated - duress",
        "type": "Arming Event",
    },
    "NE": {
        "code": "NE",
        "concerns": "Area number",
        "description": "Unsuccessful Night mode activation attempt",
        "type": "Arming Event",
    },
    "NF": {
        "code": "NF",
        "concerns": "Area number",
        "description": "Some zones/points not ready",
        "type": "Forced Perimeter Arm",
    },
    "NL": {
        "code": "NL",
        "concerns": "Area number",
        "description": "An area has been perimeter armed",
        "type": "Perimeter Armed",
    },
    "NM": {
        "code": "NM",
        "concerns": "Area number",
        "description": "A user defined area has been perimeter armed",
        "type": "Perimeter Armed, User Defined",
    },
    "NO": {
        "code": "NO",
        "concerns": "Area number",
        "description": "Night mode deactivated automatically",
        "type": "Arming Event",
    },
    "NP": {
        "code": "NP",
        "concerns": "Zone or point",
        "description": "Night mode deactivated using device",
        "type": "Arming Event",
    },
    "NR": {
        "code": "NR",
        "concerns": "Network number",
        "description": "A communications network has returned to normal operation",
        "type": "Network Restoral",
    },
    "NS": {
        "code": "NS",
        "concerns": "Zone number",
        "description": "A zone has detected activity after an alert",
        "type": "Activity Resumed",
    },
    "NT": {
        "code": "NT",
        "concerns": "Network number",
        "description": "A communications network has failed",
        "type": "Network Failure",
    },
    "OA": {
        "code": "OA",
        "concerns": "Area number",
        "description": "System has disarmed automatically",
        "type": "Automatic Opening",
    },
    "OB": {
        "code": "OB",
        "concerns": "Area number",
        "description": "Group has been disarmed automatically",
        "type": "Arming Event",
    },
    "OC": {
        "code": "OC",
        "concerns": "User number",
        "description": "Untyped zone cancel",
        "type": "Cancel Report",
    },
    "OG": {
        "code": "OG",
        "concerns": "Area number",
        "description": "System has been partially disarmed",
        "type": "Open Area",
    },
    "OH": {
        "code": "OH",
        "concerns": "User number",
        "description": "An area in alarm was disarmed before the opening window",
        "type": "Early to Open from Alarm",
    },
    "OI": {
        "code": "OI",
        "concerns": "Area number",
        "description": "An area has not been armed at the end of the opening window",
        "type": "Fail to Open",
    },
    "OJ": {
        "code": "OJ",
        "concerns": "User number",
        "description": "An area was disarmed after the opening window",
        "type": "Late Open",
    },
    "OK": {
        "code": "OK",
        "concerns": "User number",
        "description": "An area was disarmed before the opening window",
        "type": "Early Open",
    },
    "OL": {
        "code": "OL",
        "concerns": "User number",
        "description": "An area in alarm was disarmed after the opening window",
        "type": "Late to Open from Alarm",
    },
    "OP": {
        "code": "OP",
        "concerns": "User number",
        "description": "Account was disarmed",
        "type": "Opening Report",
    },
    "OQ": {
        "code": "OQ",
        "concerns": "User number",
        "description": "The system was disarmed from a remote location",
        "type": "Remote Opening",
    },
    "OR": {
        "code": "OR",
        "concerns": "User number",
        "description": "Account in alarm was reset/disarmed",
        "type": "Disarm From Alarm",
    },
    "OS": {
        "code": "OS",
        "concerns": "Zone or point",
        "description": "Account has been disarmed by keyswitch",
        "type": "Opening Keyswitch",
    },
    "OT": {
        "code": "OT",
        "concerns": "User number",
        "description": "System was not armed on time",
        "type": "Late To Close",
    },
    "OU": {
        "code": "OU",
        "concerns": "Output number",
        "description": "An output on a peripheral device or NAC is not functioning",
        "type": "Output State – Trouble",
    },
    "OV": {
        "code": "OV",
        "concerns": "Output number",
        "description": "An output on a peripheral device or NAC is back to "
        "normal operation",
        "type": "Output State – Restore",
    },
    "OZ": {
        "code": "OZ",
        "concerns": "Zone or point",
        "description": "A point, rather than a full area or account, disarmed",
        "type": "Point Opening",
    },
    "PA": {
        "code": "PA",
        "concerns": "Zone or point",
        "description": "Emergency assistance request, manually activated",
        "type": "Panic Alarm",
    },
    "PB": {
        "code": "PB",
        "concerns": "Zone or point",
        "description": "Panic zone has been bypassed",
        "type": "Panic Bypass",
    },
    "PC": {
        "code": "PC",
        "concerns": "User",
        "description": "Photo on demand enabled",
        "type": "Photo on demand enabled",
    },
    "PD": {
        "code": "PD",
        "concerns": "User",
        "description": "Photo on demand disabled",
        "type": "Photo on demand disabled",
    },
    "PE": {
        "code": "PE",
        "concerns": "Unused",
        "description": "Photo by alarm scenarios feature enabled for this hub",
        "type": "Photo by scenario enable",
    },
    "PF": {
        "code": "PF",
        "concerns": "Zone or point",
        "description": "MotionCam lost connection with hub over photos "
        "communication channel",
        "type": "Malfunction",
    },
    "PG": {
        "code": "PG",
        "concerns": "Unused",
        "description": "Photo by alarm scenarios feature disabled for this hub",
        "type": "Photo by scenario disable",
    },
    "PH": {
        "code": "PH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Panic Alarm Restore",
    },
    "PJ": {
        "code": "PJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Panic Trouble Restore",
    },
    "PO": {
        "code": "PO",
        "concerns": "Unused",
        "description": "Connection restored, device in room",
        "type": "Malfunction restore",
    },
    "PR": {
        "code": "PR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Panic Restoral",
    },
    "PS": {
        "code": "PS",
        "concerns": "Zone or point",
        "description": "Unsafe system condition exists",
        "type": "Panic Supervisory",
    },
    "PT": {
        "code": "PT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Panic Trouble",
    },
    "PU": {
        "code": "PU",
        "concerns": "Zone or point",
        "description": "Panic zone bypass has been removed",
        "type": "Panic Unbypass",
    },
    "QA": {
        "code": "QA",
        "concerns": "Zone or point",
        "description": "Emergency assistance request",
        "type": "Emergency Alarm",
    },
    "QB": {
        "code": "QB",
        "concerns": "Zone or point",
        "description": "Zone has been bypassed",
        "type": "Emergency Bypass",
    },
    "QH": {
        "code": "QH",
        "concerns": "Zone or point",
        "description": "Alarm condition has been eliminated",
        "type": "Emergency Alarm Restore",
    },
    "QJ": {
        "code": "QJ",
        "concerns": "Zone or point",
        "description": "Trouble condition has been eliminated",
        "type": "Emergency Trouble Restore",
    },
    "QR": {
        "code": "QR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Emergency Restoral",
    },
    "QS": {
        "code": "QS",
        "concerns": "Zone or point",
        "description": "Unsafe system condition exists",
        "type": "Emergency Supervisory",
    },
    "QT": {
        "code": "QT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Emergency Trouble",
    },
    "QU": {
        "code": "QU",
        "concerns": "Zone or point",
        "description": "Bypass has been removed",
        "type": "Emergency Unbypass",
    },
    "RA": {
        "code": "RA",
        "concerns": "Unused",
        "description": "Transmitter failed to communicate with the remote programmer",
        "type": "Remote Programmer Call Failed",
    },
    "RB": {
        "code": "RB",
        "concerns": "Unused",
        "description": "Remote programming session initiated",
        "type": "Remote Program Begin",
    },
    "RC": {
        "code": "RC",
        "concerns": "Relay number",
        "description": "A relay has energized",
        "type": "Relay Close",
    },
    "RD": {
        "code": "RD",
        "concerns": "Unused",
        "description": "Access passcode incorrect",
        "type": "Remote Program Denied",
    },
    "RN": {
        "code": "RN",
        "concerns": "Unused",
        "description": "A TRANSMITTER was reset via a remote programmer",
        "type": "Remote Reset",
    },
    "RO": {
        "code": "RO",
        "concerns": "Relay number",
        "description": "A relay has de-energized",
        "type": "Relay Open",
    },
    "RP": {
        "code": "RP",
        "concerns": "Unused",
        "description": "Automatic communication test report",
        "type": "Automatic Test",
    },
    "RR": {
        "code": "RR",
        "concerns": "Unused",
        "description": "System lost power, is now restored",
        "type": "Power Up",
    },
    "RS": {
        "code": "RS",
        "concerns": "Unused",
        "description": "Remote programming successful",
        "type": "Remote Program Success",
    },
    "RT": {
        "code": "RT",
        "concerns": "Line number",
        "description": "Dialer data lost, transmission error",
        "type": "Data Lost",
    },
    "RU": {
        "code": "RU",
        "concerns": "Unused",
        "description": "Remote programming unsuccessful",
        "type": "Remote Program Fail",
    },
    "RX": {
        "code": "RX",
        "concerns": "User number",
        "description": "Manual communication test report",
        "type": "Manual Test",
    },
    "RY": {
        "code": "RY",
        "concerns": "Zone or point",
        "description": "Test signal(s) indicates abnormal condition(s) exist",
        "type": "Test Off Normal",
    },
    "SA": {
        "code": "SA",
        "concerns": "Zone or point",
        "description": "Sprinkler flow condition exists",
        "type": "Sprinkler Alarm",
    },
    "SB": {
        "code": "SB",
        "concerns": "Zone or point",
        "description": "Sprinkler zone has been bypassed",
        "type": "Sprinkler Bypass",
    },
    "SC": {
        "code": "SC",
        "concerns": "Condition number",
        "description": "An expansion/peripheral device is reporting a new "
        "condition or state change",
        "type": "Change of State",
    },
    "SH": {
        "code": "SH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Sprinkler Alarm Restore",
    },
    "SJ": {
        "code": "SJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Sprinkler Trouble Restore",
    },
    "SM": {
        "code": "SM",
        "concerns": "Zone or point",
        "description": "LeakProtect Malfunction",
        "type": "Malfunction",
    },
    "SR": {
        "code": "SR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Sprinkler Restoral",
    },
    "SS": {
        "code": "SS",
        "concerns": "Zone or point",
        "description": "Unsafe sprinkler system condition",
        "type": "Sprinkler Supervisory",
    },
    "ST": {
        "code": "ST",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Sprinkler Trouble",
    },
    "SU": {
        "code": "SU",
        "concerns": "Zone or point",
        "description": "Sprinkler zone bypass has been removed",
        "type": "Sprinkler Unbypass",
    },
    "TA": {
        "code": "TA",
        "concerns": "Zone or point",
        "description": "Alarm equipment enclosure opened",
        "type": "Tamper Alarm",
    },
    "TB": {
        "code": "TB",
        "concerns": "Zone or point",
        "description": "Tamper detection has been bypassed",
        "type": "Tamper Bypass",
    },
    "TC": {
        "code": "TC",
        "concerns": "Unused",
        "description": "All point tested",
        "type": "All Points Tested",
    },
    "TE": {
        "code": "TE",
        "concerns": "Unused",
        "description": "Communicator restored to operation",
        "type": "Test End",
    },
    "TH": {
        "code": "TH",
        "concerns": "Unused",
        "description": "An Expansion Device’s tamper switch restores to "
        "normal from an Alarm state",
        "type": "Tamper Alarm Restore",
    },
    "TJ": {
        "code": "TJ",
        "concerns": "Unused",
        "description": "An Expansion Device’s tamper switch restores to "
        "normal from a Trouble state",
        "type": "Tamper Trouble Restore",
    },
    "TP": {
        "code": "TP",
        "concerns": "Point number",
        "description": "This point was tested during a Walk Test",
        "type": "Walk Test Point",
    },
    "TR": {
        "code": "TR",
        "concerns": "Zone or point",
        "description": "Alarm equipment enclosure has been closed",
        "type": "Tamper Restoral",
    },
    "TS": {
        "code": "TS",
        "concerns": "Unused",
        "description": "Communicator taken out of operation",
        "type": "Test Start",
    },
    "TT": {
        "code": "TT",
        "concerns": "Zone or point",
        "description": "Equipment enclosure opened in disarmed state",
        "type": "Tamper Trouble",
    },
    "TU": {
        "code": "TU",
        "concerns": "Zone or point",
        "description": "Tamper detection bypass has been removed",
        "type": "Tamper Unbypass",
    },
    "TW": {
        "code": "TW",
        "concerns": "Unused",
        "description": "Area watch feature has been activated",
        "type": "Area Watch Start",
    },
    "TX": {
        "code": "TX",
        "concerns": "Unused",
        "description": "An unspecified (manual or automatic) communicator test",
        "type": "Test Report",
    },
    "TZ": {
        "code": "TZ",
        "concerns": "Unused",
        "description": "Area watch feature has been deactivated",
        "type": "Area Watch End",
    },
    "UA": {
        "code": "UA",
        "concerns": "Zone or point",
        "description": "Alarm condition from zone of unknown type",
        "type": "Untyped Zone Alarm",
    },
    "UB": {
        "code": "UB",
        "concerns": "Zone or point",
        "description": "Zone of unknown type has been bypassed",
        "type": "Untyped Zone Bypass",
    },
    "UG": {
        "code": "UG",
        "concerns": "Zone or point",
        "description": "A point assigned to a Cross Point group has gone "
        "into alarm but the Cross Point remained normal",
        "type": "Unverified Event – Untyped",
    },
    "UH": {
        "code": "UH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Untyped Alarm Restore",
    },
    "UJ": {
        "code": "UJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Untyped Trouble Restore",
    },
    "UR": {
        "code": "UR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition eliminated from zone of unknown type",
        "type": "Untyped Zone Restoral",
    },
    "US": {
        "code": "US",
        "concerns": "Zone or point",
        "description": "Unsafe condition from zone of unknown type",
        "type": "Untyped Zone Supervisory",
    },
    "UT": {
        "code": "UT",
        "concerns": "Zone or point",
        "description": "Trouble condition from zone of unknown type",
        "type": "Untyped Zone Trouble",
    },
    "UU": {
        "code": "UU",
        "concerns": "Zone or point",
        "description": "Bypass on zone of unknown type has been removed",
        "type": "Untyped Zone Unbypass",
    },
    "UX": {
        "code": "UX",
        "concerns": "Unused",
        "description": "An undefined alarm condition has occurred",
        "type": "Undefined",
    },
    "UY": {
        "code": "UY",
        "concerns": "Zone or point",
        "description": "A point or device which was not armed is now logically missing",
        "type": "Untyped Missing Trouble",
    },
    "UZ": {
        "code": "UZ",
        "concerns": "Zone or point",
        "description": "A point or device which was armed is now logically missing",
        "type": "Untyped Missing Alarm",
    },
    "VI": {
        "code": "VI",
        "concerns": "Printer number",
        "description": "TRANSMITTER or RECEIVER paper in",
        "type": "Printer Paper In",
    },
    "VO": {
        "code": "VO",
        "concerns": "Printer number",
        "description": "TRANSMITTER or RECEIVER paper out",
        "type": "Printer Paper Out",
    },
    "VR": {
        "code": "VR",
        "concerns": "Printer number",
        "description": "TRANSMITTER or RECEIVER trouble restored",
        "type": "Printer Restore",
    },
    "VT": {
        "code": "VT",
        "concerns": "Printer number",
        "description": "TRANSMITTER or RECEIVER trouble",
        "type": "Printer Trouble",
    },
    "VX": {
        "code": "VX",
        "concerns": "Printer number",
        "description": "TRANSMITTER or RECEIVER test",
        "type": "Printer Test",
    },
    "VY": {
        "code": "VY",
        "concerns": "Unused",
        "description": "RECEIVER’S printer is now online",
        "type": "Printer Online",
    },
    "VZ": {
        "code": "VZ",
        "concerns": "Unused",
        "description": "RECEIVER’S printer is now offline",
        "type": "Printer Offline",
    },
    "WA": {
        "code": "WA",
        "concerns": "Zone or point",
        "description": "Water detected at protected premises",
        "type": "Water Alarm",
    },
    "WB": {
        "code": "WB",
        "concerns": "Zone or point",
        "description": "Water detection has been bypassed",
        "type": "Water Bypass",
    },
    "WH": {
        "code": "WH",
        "concerns": "Zone or point",
        "description": "Water alarm condition eliminated",
        "type": "Water Alarm Restore",
    },
    "WJ": {
        "code": "WJ",
        "concerns": "Zone or point",
        "description": "Water trouble condition eliminated",
        "type": "Water Trouble Restore",
    },
    "WR": {
        "code": "WR",
        "concerns": "Zone or point",
        "description": "Water alarm/trouble condition has been eliminated",
        "type": "Water Restoral",
    },
    "WS": {
        "code": "WS",
        "concerns": "Zone or point",
        "description": "Water unsafe water detection system condition",
        "type": "Water Supervisory",
    },
    "WT": {
        "code": "WT",
        "concerns": "Zone or point",
        "description": "Water zone disabled by fault",
        "type": "Water Trouble",
    },
    "WU": {
        "code": "WU",
        "concerns": "Zone or point",
        "description": "Water detection bypass has been removed",
        "type": "Water Unbypass",
    },
    "XA": {
        "code": "XA",
        "concerns": "Unused",
        "description": "CS RECEIVER has received an event from a non-existent account",
        "type": "Extra Account Report",
    },
    "XC": {
        "code": "XC",
        "concerns": "Unused",
        "description": "Connection restored, device in room",
        "type": "Malfunction restore",
    },
    "XE": {
        "code": "XE",
        "concerns": "Point number",
        "description": "Panel has sensed an extra point not specified for this site",
        "type": "Extra Point",
    },
    "XF": {
        "code": "XF",
        "concerns": "Point number",
        "description": "Panel has sensed an extra RF point not specified for this site",
        "type": "Extra RF Point",
    },
    "XH": {
        "code": "XH",
        "concerns": "Receiver number",
        "description": "A radio device is no longer detecting RF Interference",
        "type": "RF Interference Restoral",
    },
    "XI": {
        "code": "XI",
        "concerns": "Zone or point",
        "description": "A user has reset a sensor",
        "type": "Sensor Reset",
    },
    "XJ": {
        "code": "XJ",
        "concerns": "Receiver number",
        "description": "A Tamper condition at a premises RF Receiver has been restored",
        "type": "RF Receiver Tamper Restoral",
    },
    "XL": {
        "code": "XL",
        "concerns": "Receiver number",
        "description": "The RF signal strength of a reported event is below "
        "minimum level",
        "type": "Low Received Signal Strength/Connection Lost",
    },
    "XM": {
        "code": "XM",
        "concerns": "Zone or point",
        "description": "Missing Alarm verified by Cross Point in Alarm (or missing)",
        "type": "Missing Alarm - Cross Point",
    },
    "XQ": {
        "code": "XQ",
        "concerns": "Receiver number",
        "description": "A radio device is detecting RF Interference",
        "type": "RF Interference",
    },
    "XR": {
        "code": "XR",
        "concerns": "Zone or point",
        "description": "Low battery has been corrected",
        "type": "Transmitter Battery Restoral",
    },
    "XS": {
        "code": "XS",
        "concerns": "Receiver number",
        "description": "A Tamper condition at a premises receiver is detected",
        "type": "RF Receiver Tamper",
    },
    "XT": {
        "code": "XT",
        "concerns": "Zone or point",
        "description": "Low battery in wireless transmitter",
        "type": "Transmitter Battery Trouble",
    },
    "XW": {
        "code": "XW",
        "concerns": "Zone or point",
        "description": "A point was forced out of the system at arm time",
        "type": "Forced Point",
    },
    "XX": {
        "code": "XX",
        "concerns": "Unused",
        "description": "A specific test from a panel was not received",
        "type": "Fail to Test",
    },
    "YA": {
        "code": "YA",
        "concerns": "Unused",
        "description": "A trouble condition has been detected on a Local "
        "Bell, Siren, or Annunciator",
        "type": "Bell Fault",
    },
    "YB": {
        "code": "YB",
        "concerns": "Line card number",
        "description": "Percent of time receiver's line card is on-line",
        "type": "Busy Seconds",
    },
    "YC": {
        "code": "YC",
        "concerns": "Unused",
        "description": "RECEIVER and TRANSMITTER",
        "type": "Communications Fail",
    },
    "YD": {
        "code": "YD",
        "concerns": "Line card number",
        "description": "A line card identified by the passed address is in trouble",
        "type": "Receiver Line Card Trouble",
    },
    "YE": {
        "code": "YE",
        "concerns": "Line card number",
        "description": "A line card identified by the passed address is restored",
        "type": "Receiver Line Card Restored",
    },
    "YF": {
        "code": "YF",
        "concerns": "Unused",
        "description": "System data corrupted",
        "type": "Parameter Checksum Fail",
    },
    "YG": {
        "code": "YG",
        "concerns": "Unused",
        "description": "A TRANSMITTER’S parameters have been changed",
        "type": "Parameter Changed",
    },
    "YH": {
        "code": "YH",
        "concerns": "Unused",
        "description": "A trouble condition has been restored on a Local "
        "Bell, Siren, or Annunciator",
        "type": "Bell Restored",
    },
    "YI": {
        "code": "YI",
        "concerns": "Unused",
        "description": "An Expansion Device has detected an overcurrent condition",
        "type": "Overcurrent Trouble",
    },
    "YJ": {
        "code": "YJ",
        "concerns": "Unused",
        "description": "An Expansion Device has restored from an overcurrent condition",
        "type": "Overcurrent Restore",
    },
    "YK": {
        "code": "YK",
        "concerns": "Unused",
        "description": "TRANSMITTER has resumed communication with a RECEIVER",
        "type": "Communications Restoral",
    },
    "YM": {
        "code": "YM",
        "concerns": "Unused",
        "description": "TRANSMITTER/RECEIVER battery is missing",
        "type": "System Battery Missing",
    },
    "YN": {
        "code": "YN",
        "concerns": "Unused",
        "description": "TRANSMITTER has sent a packet with invalid data",
        "type": "Invalid Report",
    },
    "YO": {
        "code": "YO",
        "concerns": "Unused",
        "description": "An unknown message was received from automation or the printer",
        "type": "Unknown Message",
    },
    "YP": {
        "code": "YP",
        "concerns": "Unused",
        "description": "TRANSMITTER/RECEIVER has a problem with the power supply",
        "type": "Power Supply Trouble",
    },
    "YQ": {
        "code": "YQ",
        "concerns": "Unused",
        "description": "TRANSMITTER’S/RECEIVER’S power supply has been restored",
        "type": "Power Supply Restored",
    },
    "YR": {
        "code": "YR",
        "concerns": "Unused",
        "description": "Low battery has been corrected",
        "type": "System Battery Restoral",
    },
    "YS": {
        "code": "YS",
        "concerns": "Unused",
        "description": "RECEIVER and TRANSMITTER",
        "type": "Communications Trouble",
    },
    "YT": {
        "code": "YT",
        "concerns": "Unused",
        "description": "Low battery in control/communicator",
        "type": "System Battery Trouble",
    },
    "YU": {
        "code": "YU",
        "concerns": "Condition number",
        "description": "An expansion/peripheral device is reporting a diagnostic error",
        "type": "Diagnostic Error",
    },
    "YW": {
        "code": "YW",
        "concerns": "Unused",
        "description": "The TRANSMITTER created an internal reset",
        "type": "Watchdog Reset",
    },
    "YX": {
        "code": "YX",
        "concerns": "Unused",
        "description": "A TRANSMITTER/RECEIVER needs service",
        "type": "Service Required",
    },
    "YY": {
        "code": "YY",
        "concerns": "Unused",
        "description": "This is a header for an account status report transmission",
        "type": "Status Report",
    },
    "YZ": {
        "code": "YZ",
        "concerns": "Mfr defined",
        "description": "Required TRANSMITTER / RECEIVER service completed",
        "type": "Service Completed",
    },
    "ZA": {
        "code": "ZA",
        "concerns": "Zone or point",
        "description": "Low temperature detected at premises",
        "type": "Freeze Alarm",
    },
    "ZB": {
        "code": "ZB",
        "concerns": "Zone or point",
        "description": "Low temperature detection has been bypassed",
        "type": "Freeze Bypass",
    },
    "ZH": {
        "code": "ZH",
        "concerns": "Zone or point",
        "description": "Alarm condition eliminated",
        "type": "Freeze Alarm Restore",
    },
    "ZJ": {
        "code": "ZJ",
        "concerns": "Zone or point",
        "description": "Trouble condition eliminated",
        "type": "Freeze Trouble Restore",
    },
    "ZR": {
        "code": "ZR",
        "concerns": "Zone or point",
        "description": "Alarm/trouble condition has been eliminated",
        "type": "Freeze Restoral",
    },
    "ZS": {
        "code": "ZS",
        "concerns": "Zone or point",
        "description": "Unsafe freeze detection system condition",
        "type": "Freeze Supervisory",
    },
    "ZT": {
        "code": "ZT",
        "concerns": "Zone or point",
        "description": "Zone disabled by fault",
        "type": "Freeze Trouble",
    },
    "ZU": {
        "code": "ZU",
        "concerns": "Zone or point",
        "description": "Low temperature detection bypass removed",
        "type": "Freeze Unbypass",
    },
    "ZY": {
        "code": "ZY",
        "concerns": "Hub",
        "description": "Device was switched on",
        "type": "Common Event",
    },
    "ZZ": {
        "code": "ZZ",
        "concerns": "Hub",
        "description": "Device was switched off",
        "type": "Common Event",
    },
    "AE": {
        "code": "AE",
        "concerns": "Hub/Device", # Estimation basée sur la description
        "description": "hub switched to battery saving mode / ended call from company [...] due to error", # Note: Apparaît 2 fois avec des descriptions différentes dans le CSV
        "type": "Malfunction",
    },
    "AG": {
        "code": "AG",
        "concerns": "Call/Device", # Estimation basée sur la description
        "description": "ended call to company [...] via [device] in [room]",
        "type": "Common Event",
    },
    "AH": {
        "code": "AH",
        "concerns": "Call/Device", # Estimation basée sur la description
        "description": "started call to company [...] via [device] in [room]",
        "type": "Common Event",
    },
    "AI": {
        "code": "AI",
        "concerns": "Call/Device", # Estimation basée sur la description
        "description": "ended call to company [...] via [device] in [room] due to error",
        "type": "Malfunction",
    },
    "AY": {
        "code": "AY",
        "concerns": "Hub", # Estimation basée sur la description
        "description": "hub exited battery saving mode",
        "type": "Malfunction Restore",
    },
    "HV": {
        "code": "HV",
        "concerns": "System", # Estimation basée sur la description
        "description": "Hold-up alarm is confirmed",
        "type": "Alarm",
    },
    "KG": {
        "code": "KG",
        "concerns": "Keypad/User", # Estimation basée sur la description
        "description": "keypad unlocked on expiration of auto-lock time / keypad unlocked from the app by [user]", # Note: Apparaît 2 fois avec des descriptions similaires
        "type": "Malfunction Restore",
    },
    "RL": {
        "code": "RL",
        "concerns": "Keypad/Switch", # Estimation basée sur la description
        "description": "keypad locked due to unauthorized access attempt / arm switch locked due to device lid being open", # Note: Apparaît 2 fois avec des descriptions différentes
        "type": "Malfunction",
    },
    "RG": {
        "code": "RG",
        "concerns": "Switch/User", # Estimation basée sur la description
        "description": "arm switch unlocked from the app by [user]",
        "type": "Malfunction Restore",
    },
    
}
