"""Constants for SIA."""
COUNTER_EVENTS = "events"
COUNTER_VALID = "valid_events"
COUNTER_FORMAT = "format"
COUNTER_CRC = "crc"
COUNTER_CODE = "code"
COUNTER_TIMESTAMP = "timestamp"
COUNTER_ACCOUNT = "account"
COUNTER_USER_CODE = "user_code"

IV = bytes.fromhex("00000000000000000000000000000000")
EMPTY_BYTES = b""

RSP_XDATA = ["K"]
